@@ -13,7 +13,6 @@ sub render {
     my $t = Template->new({
         %$directives,
         INCLUDE_PATH => $self->path,
-        PLUGINS => $self->plugins,
         OUTPUT => \$output,
         TOLERANT => 0,
     });
@@ -24,10 +23,6 @@ sub render {
     return $output;
 }
 
-sub plugins {
-    $self->hub->registry->lookup->classes;
-}
-
 1;
 
 __DATA__
